==> openwebmail-2.30.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/nl/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Kop 1": "h1",
		"Kop 2": "h2",
		"Kop 3": "h3",
		"Kop 4": "h4",
		"Kop 5": "h5",
		"Kop 6": "h6",
		"Normaal": "p",
		"Addres": "address",
		"Niet Proportioneel": "pre"
	},

	tooltips: {
		bold:           "Vet",
		italic:         "Cursief",
		underline:      "Onderstreept",
		strikethrough:  "Doorgestreept",
		subscript:      "Subscript",
		superscript:    "Superscript",
		justifyleft:    "Links Uitlijnen",
		justifycenter:  "Centreren",
		justifyright:   "Rechts Uitlijnen",
		justifyfull:    "Verspreiden",
		insertorderedlist:    "Genummerde lijst",
		insertunorderedlist:  "Puntenlijst",
		outdent:        "Decrease Indent",
		indent:         "Increase Indent",
		forecolor:      "Karakterkleur",
		hilitecolor:    "Achtergrondkleur",
		horizontalrule: "Horizontale Lijn",
		createlink:     "Voeg Web Link toe",
		insertimage:    "Voeg afbeelding toe",
		insertsound:    "Voeg geluid toe",
		inserttable:    "Voeg tabel toe",
		htmlmode:       "Schakel tussen HTML en BRONCODE",
		popupeditor:    "Vergroot invoerveld",
		about:          "Over deze editor",
		showhelp:       "Help bij gebruik",
		textindicator:  "Huidige stijl",
		undo:           "Ongedaan maken",
		redo:           "Ongedaan maken van het ongedaan maken",
		cut:            "Knip de selectie",
		copy:           "Kopier de selectie",
		paste:          "Plak van het klembord"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Annuleren"
	},

	msg: {
		"Path":         "Pad",
		"TEXT_MODE":    "Uw TEXT MODE is actief.  Klik op de [<>] knop om de WYSIWIG mode te activeren."
	}
};

==> openwebmail-2.51p2.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/nl/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Kop 1": "h1",
		"Kop 2": "h2",
		"Kop 3": "h3",
		"Kop 4": "h4",
		"Kop 5": "h5",
		"Kop 6": "h6",
		"Normaal": "p",
		"Addres": "address",
		"Niet Proportioneel": "pre"
	},

	tooltips: {
		bold:           "Vet",
		italic:         "Cursief",
		underline:      "Onderstreept",
		strikethrough:  "Doorgestreept",
		subscript:      "Subscript",
		superscript:    "Superscript",
		justifyleft:    "Links Uitlijnen",
		justifycenter:  "Centreren",
		justifyright:   "Rechts Uitlijnen",
		justifyfull:    "Verspreiden",
		insertorderedlist:    "Genummerde lijst",
		insertunorderedlist:  "Puntenlijst",
		outdent:        "Decrease Indent",
		indent:         "Increase Indent",
		forecolor:      "Karakterkleur",
		hilitecolor:    "Achtergrondkleur",
		inserthorizontalrule: "Horizontale Lijn",
		createlink:     "Voeg Web Link toe",
		insertimage:    "Voeg afbeelding toe",
		insertsound:    "Voeg geluid toe",
		inserttable:    "Voeg tabel toe",
		htmlmode:       "Schakel tussen HTML en BRONCODE",
		popupeditor:    "Vergroot invoerveld",
		about:          "Over deze editor",
		showhelp:       "Help bij gebruik",
		textindicator:  "Huidige stijl",
		undo:           "Ongedaan maken",
		redo:           "Ongedaan maken van het ongedaan maken",
		cut:            "Knip de selectie",
		copy:           "Kopier de selectie",
		paste:          "Plak van het klembord"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Annuleren"
	},

	msg: {
		"Path":         "Pad",
		"TEXT_MODE":    "Uw TEXT MODE is actief.  Klik op de [<>] knop om de WYSIWIG mode te activeren."
	}
};
